# latam

<div align="center">

[![Build status](https://github.com/tacosdedatos/latam/workflows/build/badge.svg?branch=master&event=push)](https://github.com/tacosdedatos/latam/actions?query=workflow%3Abuild)
[![Documentation Status](https://readthedocs.org/projects/python-latam/badge/?version=latest)](https://python-latam.readthedocs.io/es/latest/?badge=latest)
[![Python Version](https://img.shields.io/pypi/pyversions/latam.svg)](https://pypi.org/project/latam/)
[![Dependencies Status](https://img.shields.io/badge/dependencies-up%20to%20date-brightgreen.svg)](https://github.com/tacosdedatos/latam/pulls?utf8=%E2%9C%93&q=is%3Apr%20author%3Aapp%2Fdependabot)

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Security: bandit](https://img.shields.io/badge/security-bandit-green.svg)](https://github.com/PyCQA/bandit)
[![Pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/tacosdedatos/latam/blob/master/.pre-commit-config.yaml)
[![Semantic Versions](https://img.shields.io/badge/%F0%9F%9A%80-semantic%20versions-informational.svg)](https://github.com/tacosdedatos/latam/releases)
[![License](https://img.shields.io/github/license/tacosdedatos/latam)](https://github.com/tacosdedatos/latam/blob/master/LICENSE)

Un paquete para trabajar facilmente con metadatos de paises en latinoamerica.
</div>

## ¿Qué trae?

## 📃 Citeishon

```
@misc{latam,
  author = {tacosdedatos},
  title = {Un paquete para trabajar facilmente con metadatos de países de Latinoamérica.},
  year = {2020},
  publisher = {GitHub},
  journal = {GitHub repository},
  howpublished = {\url{https://github.com/tacosdedatos/latam}}
}
```

> Este proyecto fue generado con [`python-package-template`](https://github.com/TezRomacH/python-package-template).
